@@ -95,10 +95,10 @@ dialogId("jes-m-netopyr3", "font_small", "It’s just an ordinary piece of rock.
 dialogStr("Het is een volkomen normaal stuk rots.")
 
 
-dialogId("jes-v-nechut0", "font_big", "I think you are going to need that 'monster’.")
+dialogId("jes-v-nechut0", "font_big", "I think you are going to need that ‘monster’.")
 dialogStr("Ik denk dat je dat monster nodig gaat hebben.")
 
 
-dialogId("jes-v-nechut1", "font_big", "I think you will have to overcome your dislike of that 'abomination’.")
+dialogId("jes-v-nechut1", "font_big", "I think you will have to overcome your dislike of that ‘abomination’.")
 dialogStr("Ik denk dat je je afkeer van dat \"misbaksel\" zult moeten overwinnen.")
 
