@@ -31,7 +31,7 @@ dialogId("wc-m-vlezt", "font_small", "Luckily, I needn’t climb inside.")
 dialogStr("Gelukkig hoef ik er niet in te zwemmen.")
 
 
-dialogId("wc-m-hrbitov", "font_small", "I don’t feel very well here. I feel like I'm in the cemetery.")
+dialogId("wc-m-hrbitov", "font_small", "I don’t feel very well here. I feel like I’m in the cemetery.")
 dialogStr("Ik voel me hier niet op m'n gemak. Het voelt als een kerkhof.")
 
 
