@@ -13,6 +13,7 @@ worldmap_addDesc("menu", "sv", "Meny", "Fish Fillets - Next Generation")
 worldmap_addDesc("menu", "sl", "Menu igre", "Fish Fillets - Next Generation")
 worldmap_addDesc("menu", "pt_BR", "Menu", "Fish Fillets - Next Generation")
 worldmap_addDesc("menu", "ru", "Меню", "Fish Fillets - Next Generation")
+worldmap_addDesc("menu", "eo", "Menuo, ", "Fish Fillets - Next Generation")
 
 worldmap_addDesc("start", "en", "How It All Started", "Fish House")
 worldmap_addDesc("start", "cs", "Jak to všechno začalo", "Rybí domeček")
@@ -27,6 +28,7 @@ worldmap_addDesc("start", "sv", "Hur allt började", "Fiskhuset")
 worldmap_addDesc("start", "sl", "Kako se je vse začelo", "Ribja hiša")
 worldmap_addDesc("start", "pt_BR", "Como Tudo Começou", "Peixaria")
 worldmap_addDesc("start", "ru", "Как всё начиналось", "Рыбий дом")
+worldmap_addDesc("start", "eo", "Kiel ĉio komenciĝis", "Fiŝa domo")
 
 worldmap_addDesc("briefcase", "en", "Briefcase Message", "Fish House")
 worldmap_addDesc("briefcase", "cs", "Podivná zásilka", "Rybí domeček")
@@ -245,7 +247,7 @@ worldmap_addDesc("viking2", "it", "Otto vichinghi in una barca", "Navi fracassat
 worldmap_addDesc("viking2", "pl", "Ośmiu wikingów w łodzi", "Cmentarzysko statków")
 worldmap_addDesc("viking2", "es", "Ocho Vikingos en un Bote", "Ruinas del Barco")
 worldmap_addDesc("viking2", "nl", "Acht vikingen in een boot", "Scheepswrakken")
-worldmap_addDesc("viking2", "bg", "Осем викинки в една лодка", "Корабни останки")
+worldmap_addDesc("viking2", "bg", "Осем викинги в една лодка", "Корабни останки")
 worldmap_addDesc("viking2", "sv", "Åtta vikingar i en båt", "Skeppsvrak")
 worldmap_addDesc("viking2", "sl", "Osem vikingov v čolnu", "Ladijske razbitine")
 worldmap_addDesc("viking2", "pt_BR", "Oito Vikings em um Navio", "Destroços do Navio")
@@ -301,6 +303,7 @@ worldmap_addDesc("city", "it", "Benvenuti nella nostra città", "Città profonda
 worldmap_addDesc("city", "pl", "Witajcie w naszym mieście", "Miasto w głębinach")
 worldmap_addDesc("city", "es", "Bienvenido a nuestra Ciudad", "Ciudad en lo Profundo")
 worldmap_addDesc("city", "nl", "Welkom in onze stad", "De verzonken stad")
+worldmap_addDesc("city", "bg", "Добре дошли в нашия град", "Потъналият град")
 worldmap_addDesc("city", "sv", "Välkommen till vår stad", "Staden i djupet")
 worldmap_addDesc("city", "sl", "Dobrodošli v našem mestu", "Mesto v Globini")
 worldmap_addDesc("city", "pt_BR", "Bem vindo à Nossa Cidade", "A Cidade Profunda")
@@ -330,6 +333,7 @@ worldmap_addDesc("columns", "es", "Las Columnas", "Ciudad en lo Profundo")
 worldmap_addDesc("columns", "nl", "De pilaren", "De verzonken stad")
 worldmap_addDesc("columns", "bg", "Колоните", "Потъналият град")
 worldmap_addDesc("columns", "sv", "Pelarna", "Staden i djupet")
+worldmap_addDesc("columns", "sl", "Stebri", "Mesto v Globini")
 worldmap_addDesc("columns", "pt_BR", "As Colunas", "A Cidade Profunda")
 worldmap_addDesc("columns", "ru", "Колонны", "Город на глубине")
 
@@ -343,6 +347,7 @@ worldmap_addDesc("pavement", "es", "Pavimento en Desnivel", "Ciudad en lo Profun
 worldmap_addDesc("pavement", "nl", "Hobbelig trottoir", "De verzonken stad")
 worldmap_addDesc("pavement", "bg", "Неравен паваж", "Потъналият град")
 worldmap_addDesc("pavement", "sv", "Ojämn trottoar", "Staden i djupet")
+worldmap_addDesc("pavement", "sl", "Neraven pločnik", "Mesto v Globini")
 worldmap_addDesc("pavement", "pt_BR", "Pavimento Irregular", "A Cidade Profunda")
 worldmap_addDesc("pavement", "ru", "Неровный тротуар", "Город на глубине")
 
@@ -356,6 +361,7 @@ worldmap_addDesc("pyramid", "es", "La Casa de Mr. Cheops", "Ciudad en lo Profund
 worldmap_addDesc("pyramid", "nl", "Het huis van Cheops", "De verzonken stad")
 worldmap_addDesc("pyramid", "bg", "Къщата на г-н Хеопс", "Потъналият град")
 worldmap_addDesc("pyramid", "sv", "Cheops hus", "Staden i djupet")
+worldmap_addDesc("pyramid", "sl", "Keopsova hiša", "Mesto v Globini")
 worldmap_addDesc("pyramid", "pt_BR", "A Casa do Sr. Cheops", "A Cidade Profunda")
 worldmap_addDesc("pyramid", "ru", "Дом мистера Хеопса", "Город на глубине")
 
@@ -369,6 +375,7 @@ worldmap_addDesc("music", "es", "Un Poco de Música", "Ciudad en lo Profundo")
 worldmap_addDesc("music", "nl", "Een beetje muziek", "De verzonken stad")
 worldmap_addDesc("music", "bg", "Малко музика", "Потъналият град")
 worldmap_addDesc("music", "sv", "Lite musik", "Staden i djupet")
+worldmap_addDesc("music", "sl", "Malo glasbe", "Mesto v Globini")
 worldmap_addDesc("music", "pt_BR", "Um Pouco de Música", "A Cidade Profunda")
 worldmap_addDesc("music", "ru", "Немного музыки", "Город на глубине")
 
@@ -382,6 +389,7 @@ worldmap_addDesc("crabshow", "es", "Loco Show del Cangrejo", "Ciudad en lo Profu
 worldmap_addDesc("crabshow", "nl", "Krabbenrariteitenkabinet", "De verzonken stad")
 worldmap_addDesc("crabshow", "bg", "Шоуто на лудия рак", "Потъналият град")
 worldmap_addDesc("crabshow", "sv", "Krabbmonstershow", "Staden i djupet")
+worldmap_addDesc("crabshow", "sl", "Razstava rakovskih spak", "Mesto v Globini")
 worldmap_addDesc("crabshow", "pt_BR", "Show Maluco do Caranguejo", "A Cidade Profunda")
 worldmap_addDesc("crabshow", "ru", "Шоу причудливых крабов", "Город на глубине")
 
@@ -395,6 +403,7 @@ worldmap_addDesc("elevator2", "es", "Otro Ascensor", "Ciudad en lo Profundo")
 worldmap_addDesc("elevator2", "nl", "Nog een lift", "De verzonken stad")
 worldmap_addDesc("elevator2", "bg", "Още един асаньор", "Потъналият град")
 worldmap_addDesc("elevator2", "sv", "Ännu en hiss", "Staden i djupet")
+worldmap_addDesc("elevator2", "sl", "Še eno dvigalo", "Mesto v Globini")
 worldmap_addDesc("elevator2", "pt_BR", "Outro Elevador", "A Cidade Profunda")
 worldmap_addDesc("elevator2", "ru", "Еще один лифт", "Город на глубине")
 
@@ -408,6 +417,7 @@ worldmap_addDesc("atlantis", "es", "Y Cómo Era",  "Ciudad en lo Profundo")
 worldmap_addDesc("atlantis", "nl", "Hoe het zat",  "De verzonken stad")
 worldmap_addDesc("atlantis", "bg", "Така беше едно време", "Потъналият град")
 worldmap_addDesc("atlantis", "sv", "Som det var", "Staden i djupet")
+worldmap_addDesc("atlantis", "sl", "Kako je bilo", "Mesto v Globini")
 worldmap_addDesc("atlantis", "pt_BR", "E Como Era", "A Cidade Profunda")
 worldmap_addDesc("atlantis", "ru", "Вот как это было",  "Город на глубине")
 
@@ -601,7 +611,7 @@ worldmap_addDesc("barrel", "it", "Greenpeace oltraggiata", "Pattumiera")
 worldmap_addDesc("barrel", "pl", "Obraza Greenpeace", "Śmietnisko")
 worldmap_addDesc("barrel", "es", "Greenpeace Ultrajado", "Vertedero")
 worldmap_addDesc("barrel", "nl", "Boze Greenpeace", "Vuilnis")
-worldmap_addDesc("barrel", "bg", "Оскърбен Greenpeace", "Боклук")
+worldmap_addDesc("barrel", "bg", "Оскърбен Грийнпийсe", "Боклук")
 worldmap_addDesc("barrel", "sv", "Uppretat Greenpeace", "Avfall")
 worldmap_addDesc("barrel", "pt_BR", "Greenpeace Revoltado", "Aterro")
 worldmap_addDesc("barrel", "ru", "Оскорблённый «Гринпис»", "Свалка")
@@ -705,6 +715,7 @@ worldmap_addDesc("reactor", "it", "Centrale elettrica", "UFO")
 worldmap_addDesc("reactor", "pl", "Reaktor", "UFO")
 worldmap_addDesc("reactor", "es", "Central Eléctrica", "OVNI")
 worldmap_addDesc("reactor", "nl", "Reactor", "Vliegende schotel")
+worldmap_addDesc("reactor", "bg", "Реактор", "НЛО")
 worldmap_addDesc("reactor", "sv", "Reaktor", "UFO")
 worldmap_addDesc("reactor", "pt_BR", "Estação de Força", "UFO")
 worldmap_addDesc("reactor", "ru", "Электростанция", "НЛО")
@@ -885,7 +896,7 @@ worldmap_addDesc("emulator", "it", "Emulatore", "Il computer segreto")
 worldmap_addDesc("emulator", "pl", "Emulator", "Tajemniczy komputer")
 worldmap_addDesc("emulator", "es", "Emulador", "Computador Secreto")
 worldmap_addDesc("emulator", "nl", "Emulator", "Geheime computer")
-worldmap_addDesc("emulator", "bg", "Енулатор", "Тайният компютър")
+worldmap_addDesc("emulator", "bg", "Емулатор", "Тайният компютър")
 worldmap_addDesc("emulator", "sv", "Emulator", "Hemlig dator")
 worldmap_addDesc("emulator", "pt_BR", "Emulador", "Computador Secreto")
 worldmap_addDesc("emulator", "ru", "Эмулятор", "Секретный компьютер")
@@ -974,7 +985,7 @@ worldmap_addDesc("fdto", "de", "Haus FDTO", "Zweig der neuen Generation")
 worldmap_addDesc("fdto", "pl", "Kwatera FDTO", "NG")
 worldmap_addDesc("fdto", "sv", "FDTO högkvarter", "Gren av en ny generation")
 worldmap_addDesc("fdto", "nl", "Het VDTO gebouw", "Vissenhuis")
-worldmap_addDesc("fdto", "bg", "Сградата на ООРД", "NG")
+worldmap_addDesc("fdto", "bg", "Сградата на ООРД", "Нова генерация")
 worldmap_addDesc("fdto", "sl", "Zgradba RDA", "NG")
 worldmap_addDesc("fdto", "pt_BR", "Casa FDTO?", "NG")
 worldmap_addDesc("fdto", "ru", "Здание FDTO", "Новая ветвь в NG")
@@ -984,13 +995,31 @@ worldmap_addDesc("hole", "de", "Tiefer Graben", "Zweig der neuen Generation")
 worldmap_addDesc("hole", "cs", "Nepříjemná propast", "Větev Nové generace")
 worldmap_addDesc("hole", "sv", "Svårt hål", "Gren av en ny generation")
 worldmap_addDesc("hole", "nl", "Een diep gat", "Tak van de nieuwe generatie")
+worldmap_addDesc("hole", "bg", "Трудна дупка", "Нова генерация")
 worldmap_addDesc("hole", "ru", "Тяжёлая луза", "Новая ветвь в NG")
 
+worldmap_addDesc("key", "en", "Lock and Key", "Branch of New Generation")
+worldmap_addDesc("key", "de", "Schlüssel und Schloß", "Zweig der neuen Generation")
+worldmap_addDesc("key", "cs", "Zámek a klíč", "Větev Nové generace")
+worldmap_addDesc("key", "sv", "Lås och nyckel", "Gren av en ny generation")
+worldmap_addDesc("key", "nl", "Slot en grendel", "Tak van de nieuwe generatie")
+worldmap_addDesc("key", "bg", "Под ключ", "Нова генерация")
+worldmap_addDesc("key", "ru", "Замок и Ключ", "Новая ветвь в NG")
+
+worldmap_addDesc("keys", "en", "Locksmithery", "Branch of New Generation")
+worldmap_addDesc("keys", "de", "Schlosserei", "Zweig der neuen Generation")
+worldmap_addDesc("keys", "cs", "Zámečnictví", "Větev Nové generace")
+worldmap_addDesc("keys", "sv", "Låssmide", "Gren av en ny generation")
+worldmap_addDesc("keys", "nl", "Slotenmakerij", "Tak van de nieuwe generatie")
+worldmap_addDesc("keys", "bg", "Ключарница", "Нова генерация")
+worldmap_addDesc("keys", "ru", "Слесарь", "Новая ветвь в NG")
+
 worldmap_addDesc("hanoi", "en", "Separated", "Branch of New Generation")
 worldmap_addDesc("hanoi", "de", "Getrennt", "Zweig der neuen Generation")
 worldmap_addDesc("hanoi", "cs", "Odděleni", "Větev Nové Generace")
 worldmap_addDesc("hanoi", "sv", "Separerade", "Gren av en ny generation")
 worldmap_addDesc("hanoi", "nl", "Uitelkaar", "Tak van de nieuwe generatie")
+worldmap_addDesc("hanoi", "bg", "Разделени", "Нова генерация")
 worldmap_addDesc("hanoi", "ru", "Отделение", "Новая ветвь в NG")
 
 worldmap_addDesc("rush", "en", "Filled Car Park", "Branch of New Generation")
@@ -998,6 +1027,7 @@ worldmap_addDesc("rush", "de", "Voller Parkplatz", "Zweig der neuen Generation")
 worldmap_addDesc("rush", "cs", "Zaplněné parkoviště", "Větev Nové Generace")
 worldmap_addDesc("rush", "sv", "Full parkering", "Gren av en ny generation")
 worldmap_addDesc("rush", "nl", "Volle parkeerplek", "Tak van de nieuwe generatie")
+worldmap_addDesc("rush", "bg", "Запълнен паркинг", "Нова генерация")
 worldmap_addDesc("rush", "ru", "Полная стоянка", "Новая ветвь в NG")
 
 worldmap_addDesc("nowall", "en", "No Wall at All", "Branch of New Generation")
@@ -1005,11 +1035,28 @@ worldmap_addDesc("nowall", "de", "Keine Wände", "Zweig der neuen Generation")
 worldmap_addDesc("nowall", "cs", "Vůbec žádná zeď", "Větev Nové Generace")
 worldmap_addDesc("nowall", "sv", "Inga väggar alls", "Gren av en ny generation")
 worldmap_addDesc("nowall", "nl", "Helemaal geen muren", "Tak van de nieuwe generatie")
+worldmap_addDesc("nowall", "bg", "Съвсем без стени", "Нова генерация")
 worldmap_addDesc("nowall", "ru", "Нигде нет стен.", "Новая ветвь в NG")
 
 worldmap_addDesc("rotate", "en", "Rotate It", "Branch of New generation")
+worldmap_addDesc("rotate", "de", "Dreh es", "Zweig der neuen Generation")
 worldmap_addDesc("rotate", "cs", "Roztočte to", "Větev Nové generace")
 worldmap_addDesc("rotate", "sv", "Rotera den", "Gren av en ny generation")
 worldmap_addDesc("rotate", "nl", "Draai Het", "Gren av en ny generation")
+worldmap_addDesc("rotate", "bg", "Завъртете това", "Нова генерация")
 worldmap_addDesc("rotate", "ru", "Поверните это", "Новая ветвь в NG")
 
+worldmap_addDesc("linux", "en", "Linuxers Must Be Mad", "Branch of New Generation")
+worldmap_addDesc("linux", "de", "Linuxbenutzer müssen verrückt sein", "Zweig der neuen Generation")
+worldmap_addDesc("linux", "cs", "Linuxáci musí být šílení", "Větev Nové Generace")
+worldmap_addDesc("linux", "ru", "Линуксойд должен быть сумашедшим", "Новая ветвь в NG")
+worldmap_addDesc("linux", "sv", "Linuxanvändare måste vara tokiga", "Gren av en ny generation")
+worldmap_addDesc("linux", "bg", "Линуксаджиите сигурно са полудели", "Нова генерация")
+
+worldmap_addDesc("electromagnet", "en", "Electromagnet", "UFO Exit")
+worldmap_addDesc("electromagnet", "de", "Elektromagnet", "Zweig der neuen Generation")
+worldmap_addDesc("electromagnet", "cs", "Elektromagnet", "UFO únik")
+worldmap_addDesc("electromagnet", "bg", "Електромагнит", "Изход от НЛО")
+worldmap_addDesc("electromagnet", "sv", "Elektromagnet", "UFOutgång")
+worldmap_addDesc("electromagnet", "ru", "Электромагнит", "Ветка из НЛО")
+
