@@ -13,12 +13,12 @@ node_bestSolution("party1", 236, "Mark Byers")
 node_bestSolution("elk", 257, "Pavel Danihelka")
 node_bestSolution("wreck", 91, "Hynek Vychodil")
 node_bestSolution("viking1", 119, "Pavel Danihelka")
-node_bestSolution("airplane", 237, "Johan Rönnblom")
+node_bestSolution("airplane", 235, "Johannes Drescher")
 node_bestSolution("bathyscaph", 82, "Pavel Danihelka")
 node_bestSolution("tank", 402, "Josef Peterka")
 node_bestSolution("viking2", 349, "Gabor Braun")
 node_bestSolution("party2", 283, "Gabor Braun")
-node_bestSolution("gods", 593, "Gabor Braun")
+node_bestSolution("gods", 537, "Masaaki Irie")
  
 node_bestSolution("elevator1", 200, "Pavel Danihelka")
 node_bestSolution("city", 481, "Gabor Braun")
@@ -34,7 +34,7 @@ node_bestSolution("atlantis", 531, "Uoti Urpala")
 node_bestSolution("corals", 256, "Josef Peterka")
 node_bestSolution("labyrinth", 278, "Mark Byers")
 node_bestSolution("imprisoned", 275, "Josef Peterka")
-node_bestSolution("society", 114, "Gabor Braun")
+node_bestSolution("society", 110, "Radovan Málek")
 node_bestSolution("creatures", 447, "Josef Peterka")
 node_bestSolution("cancan", 578, "Mark Byers")
 node_bestSolution("pearls", 487, "Gabor Braun")
@@ -52,8 +52,8 @@ node_bestSolution("cabin1", 168, "Pavel Danihelka")
 node_bestSolution("snowman", 66, "Pavel Danihelka")
 node_bestSolution("cannons", 39, "Pavel Danihelka")
 node_bestSolution("kitchen", 564, "Josef Peterka")
-node_bestSolution("cabin2", 387, "Brian Raiter")
-node_bestSolution("captain", 539, "Gabor Braun")
+node_bestSolution("cabin2", 383, "David Glass")
+node_bestSolution("captain", 483, "David Glass")
 node_bestSolution("map", 1541, "Gabor Braun")
  
 node_bestSolution("reactor", 163, "Pavel Danihelka")
@@ -74,13 +74,15 @@ node_bestSolution("grail", 1725, "Gabor Braun")
 node_bestSolution("tetris", 134, "Gabor Braun")
 node_bestSolution("emulator", 620, "Gabor Braun")
 node_bestSolution("warcraft", 573, "Josef Peterka")
-node_bestSolution("windoze", 553, "Gabor Braun")
-node_bestSolution("hardware", 635, "Gabor Braun")
+node_bestSolution("windoze", 549, "David Glass")
+node_bestSolution("hardware", 631, "Masaaki Irie")
 node_bestSolution("floppy", 998, "Gabor Braun")
  
-node_bestSolution("hanoi", 432, "Miroslav Olšák")
+node_bestSolution("hanoi", 404, "Masaaki Irie")
 node_bestSolution("rush", 852, "Miroslav Olšák")
 node_bestSolution("fdto", 251, "Ronny Standtke")
---node_bestSolution("rotate", 213, "Miroslav Olsak")
---node_bestSolution("nowall", 566, "Miroslav Olsak")
---node_bestSolution("hole", 499, "Miroslav Olsak")
+node_bestSolution("rotate", 213, "Masaaki Irie")
+node_bestSolution("nowall", 418, "Masaaki Irie")
+node_bestSolution("hole", 499, "Miroslav Olšák")
+node_bestSolution("key", 834, "Masaaki Irie")
+node_bestSolution("keys", 283, "Masaaki Irie")
